@@ -14,11 +14,11 @@ import unittest
 from pathlib import Path
 
 import kalasiris as isis
-from .utils import resource_check as rc
-
-
-run_real_files = True
-run_real_files_reason = "Tests on real files, and runs ISIS."
+from .utils import (
+    resource_check as rc,
+    real_files as run_real_files,
+    real_files_reason as run_real_files_reason
+)
 
 # Hardcoding this, but I sure would like a better solution.
 HiRISE_img = Path("test-resources") / "PSP_010502_2090_RED5_0.img"
@@ -215,7 +215,10 @@ class TestHistogram_filesystem(unittest.TestCase):
 
     def test_listlike(self):
         h = isis.Histogram(self.histfile)
-        self.assertEqual(5, len(h[0]))
+        cols = 6
+        if tuple(isis.version.version_info()[:3]) < (4, 3, 0):
+            cols = 5
+        self.assertEqual(cols, len(h[0]))
 
     def test_contains(self):
         h = isis.Histogram(self.histfile)
