@@ -14,10 +14,11 @@ import unittest
 from pathlib import Path
 
 import kalasiris as isis
-from .utils import resource_check as rc
-
-run_real_files = True
-run_real_files_reason = "Tests on real files, and runs ISIS."
+from .utils import (
+    resource_check as rc,
+    real_files as run_real_files,
+    real_files_reason as run_real_files_reason
+)
 
 # Hardcoding this, but I sure would like a better solution.
 HiRISE_img = Path("test-resources") / "PSP_010502_2090_RED5_0.img"
@@ -34,9 +35,14 @@ class TestResources(unittest.TestCase):
 
 
 class TestBasic(unittest.TestCase):
+    def setUp(self):
+        self.d = {"StartByte": "10", "Bytes": "20"}
+
     def test_get_start_size(self):
-        d = {"StartByte": "10", "Bytes": "20"}
-        self.assertEqual((9, 20), isis.cube._get_start_size(d))
+        self.assertEqual((9, 20), isis.cube._get_start_size(self.d))
+
+    def test_get_startsize_from(self):
+        self.assertEqual((9, 20), isis.cube.get_startsize_from(self.d))
 
 
 @unittest.skipUnless(run_real_files, run_real_files_reason)
@@ -50,6 +56,13 @@ class TestTable(unittest.TestCase):
             Path("print.prt").unlink()
         self.cube.unlink()
 
+    def test_get_startsize_from(self):
+        (start, size) = isis.cube.get_startsize_from(
+            table_name="HiRISE Calibration Ancillary", cube_path=self.cube
+        )
+        self.assertEqual(7440, size)
+        self.assertAlmostEqual(4162038, start, delta=8)
+
     def test_read_table_data(self):
         self.assertRaises(ValueError, isis.cube.read_table_data, self.cube)
         self.assertRaises(
