@@ -12,6 +12,9 @@
 import collections
 from pathlib import Path
 
+real_files = True
+real_files_reason = "Tests on real files, and runs ISIS."
+
 
 def resource_check(*args):
     """Checks to see if the files exist. And returns a tuple.
